from quickff import *

#--- Defining the system ---

#read system from input files
system = System.from_files(['gaussian.fchk'])

#guess atom types
system.guess_ffatypes('low')

#determine internal coordinates from topology
#system.determine_ics_from_topology(stretch_pot_kind='spf', bend_pot_kind='harmcos')
system.determine_ics_from_topology()

#--- Defining the model and program ---

model = Model.from_system(system, ai_project=True)
#model = Model.from_system(system, ai_project=False, stretch_pot_kind='spf', bend_pot_kind='harmcos')
program = Program(system, model)

#--- Constructing the force field ---

#estimate rest angle and multiplicity of dihedral potentials from geometry
model.val.determine_dihedral_potentials(system)

#Determine the coordinates of the perturbation trajectories
trajectories = program.generate_trajectories()

#Estimating all pars for bonds, bends and opdists
fftab = program.estimate_from_pt(trajectories)
#fftab = program.estimate_from_pt(trajectories, stretch_pot_kind='spf', bend_pot_kind='harmcos')

#Refining force constants using a Hessian LSQ cost
fftab = program.refine_cost()

#--- Generating output ---

fftab.print_screen()
fftab.dump_ffit2('pars_ffit2.txt')
fftab.dump_yaff('pars_yaff.txt')
